@@ -166,6 +166,18 @@ class Medialoopster:
 
         return response.json()
 
+    def set_date_add_asset(self, asset_id, date_add, asset_type="videoassets"):
+        url = f"{self.url}{asset_type}/{asset_id}/"
+
+        request = {
+            "date_add": date_add
+        }
+
+        response = self.session.patch(url, json=request)
+        response.raise_for_status()
+
+        return response.json()
+
     def edit_meta_field_store(self, asset_id, meta_field_store, asset_type="videoassets"):
         url = f"{self.url}{asset_type}/{asset_id}/"
 
